@@ -20,10 +20,6 @@ OC.L10N.register(
     "Saved" : "Запазено",
     "Download" : "Изтегли",
     "Close" : "Затваряне",
-    "filter" : "филтър",
-    "Language" : "Език",
-    "Subscribe" : "Абониране",
-    "Got more awesome feeds? Share them with us!" : "Разполагате със страхотни емисии? Споделете ги!",
     "No articles available" : "Няма статии",
     "No unread articles available" : "Няма непрочетени статии",
     "Open website" : "Отвори интернет станица",
@@ -57,6 +53,7 @@ OC.L10N.register(
     "Mark current article's feed/folder read" : "Означи статиите от текущият поток/папка като прочетени",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Засечен е Ajax или webcron режим! Емисиите няма да бъдат актуализирани!",
     "How to set up the operating system cron" : "Как се настройва работещия системен cron",
+    "Subscribe" : "Абониране",
     "Web address" : "Уеб адрес",
     "Feed exists already!" : "Емисията вече съществува!",
     "Folder" : "Папка",
