@@ -18,9 +18,6 @@ OC.L10N.register(
     "Saved" : "Salvestatud",
     "Download" : "Lae alla",
     "Close" : "Sulge",
-    "filter" : "filter",
-    "Language" : "Keel",
-    "Subscribe" : "Telli",
     "No articles available" : "Ühtegi artiklit pole saadaval",
     "No unread articles available" : "Lugemata artikleid pole saadaval",
     "Open website" : "Ava veebisait",
@@ -53,6 +50,7 @@ OC.L10N.register(
     "Mark current article's feed/folder read" : "Märgi praegused artikli vood/kaustad loetuks",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax või webcron aktiveeritud! Su voogusid ei uuendata!",
     "How to set up the operating system cron" : "Kuidas seadistada operatsioonisüsteemi ajastatud tegevust",
+    "Subscribe" : "Telli",
     "Web address" : "Veebiaadress",
     "Feed exists already!" : "Uudisvoog on juba olemas!",
     "Folder" : "Kaust",
