@@ -1,12 +1,12 @@
 OC.L10N.register(
     "news",
     {
-    "Request failed, network connection unavailable!" : "Pyyntö epäonnistui, verkkoyhteyttä ei ole käytettävissä!",
+    "Request failed, network connection unavailable!" : "Pyyntö epäonnistui, verkkoyhteys ei ole käytettävissä!",
     "Request unauthorized. Are you logged in?" : "Pyyntö ei ole valtutettu. Oletko sisäänkirjautuneena?",
     "Request forbidden. Are you an admin?" : "Pyyntö evätty. Oletko ylläpitäjä?",
-    "Token expired or app not enabled! Reload the page!" : "Valtuutus vanheni tai sovellus ei käytössä. Lataa sivu uudelleen.",
-    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Sisäinen palvelinvirhe! Tarkista tiedosto data/nextcloud.log saadaksesi lisätietoja!",
-    "Request failed, Nextcloud is in currently in maintenance mode!" : "Pyyntö epäonnistui, Nextcloud on parhaillaan huoltotilassa!",
+    "Token expired or app not enabled! Reload the page!" : "Valtuutus vanheni tai sovellus ei ole käytössä! Lataa sivu uudelleen!",
+    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Sisäinen palvelinvirhe! Tarkista lisätiedot lokitiedostosta data/nextcloud.log!",
+    "Request failed, Nextcloud is in currently in maintenance mode!" : "Pyyntö epäonnistui, Nextcloud on parhaillaan ylläpitotilassa!",
     "Can not add feed: Unable to parse feed" : "Syötettä ei voi lisätä: syötteen jäsentäminen epäonnistui",
     "Can not add feed: Exists already" : "Syötettä ei voi lisätä: se on jo olemassa",
     "Articles without feed" : "Vailla syötettä olevat artikkelit",
@@ -14,28 +14,28 @@ OC.L10N.register(
     "News" : "Uutiset",
     "An RSS/Atom feed reader" : "RSS-/Atom-syötteiden lukija",
     "Use system cron for updates" : "Käytä järjestelmän cronia päivityksille",
+    "Disable this if you run a custom updater such as the Python updater included in the app." : "Poista tämä käytöstä jos käytät muuta päivittäjää, kuten sovelluksen Python-päivittäjää.",
     "Purge interval" : "Hävitysväli",
-    "Maximum read count per feed" : "Syötekohtaisten lukukertojen enimmäismäärä",
+    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Minimiaika sekunteina jonka jälkeen poistetut syötteet ja kansiot poistetaan tietokannasta; alle 60 sekuntin arvot ohitetaan.",
+    "Maximum read count per feed" : "Syötekohtainen lukukertojen enimmäismäärä",
     "Maximum redirects" : "Uudelleenohjausten enimmäismäärä",
     "How many redirects the feed fetcher should follow." : "Kuinka montaa uudelleenohjausta syötteen noutajan tulisi seurata.",
     "Feed fetcher timeout" : "Syötteen hakemisen aikakatkaisu",
+    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimiaika sekunteina, jonka aikana RSS- tai Atom-syöte odotetaan ladattavaksi. Jos lataus kestää pidempään, se perutaan.",
     "For more information check the wiki." : "Lue lisätietoja wikistä.",
     "Update interval" : "Päivitysväli",
+    "Interval in seconds in which the feeds will be updated." : "Syötteiden päivitysväli sekunteina.",
     "Saved" : "Tallennettu",
     "Download" : "Lataa",
     "Close" : "Sulje",
-    "filter" : "suodatin",
-    "Language" : "Kieli",
-    "Subscribe" : "Tilaa",
-    "Got more awesome feeds? Share them with us!" : "Onko sinulla lisää erinomaisia syötteitä? Jaa ne kanssamme!",
-    "No articles available" : "Artikkeleja ei ole saatavilla",
-    "No unread articles available" : "Lukemattomia artikkeleja ei ole saatavilla",
+    "No articles available" : "Artikkeleita ei ole saatavilla",
+    "No unread articles available" : "Lukemattomia artikkeleita ei ole saatavilla",
     "Open website" : "Avaa verkkosivu",
     "Star article" : "Merkitse artikkeli tähdellä",
     "Unstar article" : "Poista artikkelin tähtimerkintä",
     "Keep article unread" : "Pidä artikkeli lukemattomana",
     "Remove keep article unread" : "Poista artikkelin pitäminen lukemattomana",
-    "by" : " Kirjoittaja:",
+    "by" : "Kirjoittaja:",
     "from" : "Syöte:",
     "Play audio" : "Toista äänet",
     "Download audio" : "Lataa äänet",
@@ -56,9 +56,13 @@ OC.L10N.register(
     "Load previous feed" : "Lataa edellinen syöte",
     "Load next folder" : "Lataa seuraava kansio",
     "Load previous folder" : "Lataa edellinen kansio",
+    "Scroll to active navigation entry" : "Vieritä syötelista aktiivisen syötteen kohdalle",
     "Focus search field" : "Kohdista hakukenttään",
     "Mark current article's feed/folder read" : "Merkitse nykyisen artikkelin syöte/kansio luetuksi",
+    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax tai webcron on käytössä! Syötteitä ei päivitetä!",
     "How to set up the operating system cron" : "Käyttöjärjestelmän cronin asettaminen",
+    "Install and set up a faster parallel updater that uses the News app's update API" : "Asenna ja ota käyttöön rinnakkainen päivitys käyttäen News-sovelluksen API:a",
+    "Subscribe" : "Tilaa",
     "Web address" : "Verkko-osoite",
     "Feed exists already!" : "Syöte on jo olemassa!",
     "Folder" : "Kansio",
