@@ -19,10 +19,6 @@ OC.L10N.register(
     "Saved" : "Disimpan",
     "Download" : "Unduh",
     "Close" : "Tutup",
-    "filter" : "filter",
-    "Language" : "Bahasa",
-    "Subscribe" : "Berlangganan",
-    "Got more awesome feeds? Share them with us!" : "Punya feed yang lebih bagus? Bagikan kepada kami!",
     "No articles available" : "Tidak ada artikel yang tersedia",
     "No unread articles available" : "Tidak ada artikel yang belum dibaca",
     "Open website" : "Buka situs web",
@@ -56,6 +52,7 @@ OC.L10N.register(
     "Mark current article's feed/folder read" : "Tandai feed/folder artikel saat ini telah dibaca",
     "How to set up the operating system cron" : "Bagaimana cara menyetel cron sistem operasi",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Pasang dan atur pembaruan paralel yang lebih cepat yang menggunakan API pembaruan aplikasi Berita",
+    "Subscribe" : "Berlangganan",
     "Web address" : "Alamat web",
     "Feed exists already!" : "Feed sudah ada!",
     "Folder" : "Folder",
