@@ -20,10 +20,6 @@ OC.L10N.register(
     "Saved" : "შენახულია",
     "Download" : "ჩამოტვირთვა",
     "Close" : "დახურვა",
-    "filter" : "ფილტრი",
-    "Language" : "ენა",
-    "Subscribe" : "გამოწერა",
-    "Got more awesome feeds? Share them with us!" : "კიდევ გაქვთ კარგი ლენტები? გაგვიზიარეთ!",
     "No articles available" : "არტიკლები ხელმიუწვდომელია",
     "No unread articles available" : "წაუკითხავი არტიკლები არაა",
     "Open website" : "ვებ-საიტის გახსნა",
@@ -58,6 +54,7 @@ OC.L10N.register(
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "არჩეულია Ajax-ის ან webcron-ის რეჟიმი! თქვენი ლენტა არ განახლდება!",
     "How to set up the operating system cron" : "როგორ დავაყენოთ ოპერაციული სისტემის კრონი",
     "Install and set up a faster parallel updater that uses the News app's update API" : "დააყენეთ და მოაწყვეთ უფრო სწრაფი პარალელური განახლება რომელიც მოიხმარს სიახლეების აპლიკაციის განახლების პროგრამულ ინტერფეისს",
+    "Subscribe" : "გამოწერა",
     "Web address" : "Web მისამართი",
     "Feed exists already!" : "ლენტა უკვე არსებობს!",
     "Folder" : "დირექტორია",
