@@ -21,10 +21,6 @@ OC.L10N.register(
     "Saved" : "Lagret",
     "Download" : "Last ned",
     "Close" : "Lukk",
-    "filter" : "filter",
-    "Language" : "Språk",
-    "Subscribe" : "Abonner",
-    "Got more awesome feeds? Share them with us!" : "Har du flere fantastiske strømmer? Del dem med oss!",
     "No articles available" : "Ingen artikler tilgjengelig",
     "No unread articles available" : "Ingen uleste artikler tilgjengelig",
     "Open website" : "Åpne nettside",
@@ -59,6 +55,7 @@ OC.L10N.register(
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eller webcron-metode påvist! Strømmene dine vil ikke bli oppdaterte!",
     "How to set up the operating system cron" : "Hvordan sette opp operativsystemets Cron",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Installer og sett opp en raskere parallel oppdaterer som bruker nyhetsappens oppdaterings-API",
+    "Subscribe" : "Abonner",
     "Web address" : "Internettadresse",
     "Feed exists already!" : "Strømmen finnes allerede!",
     "Folder" : "Mappe",
