@@ -16,6 +16,7 @@ use Doctrine\DBAL\FetchMode;
 use OCA\News\Utility\Time;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Db\Entity;
+use OCP\AppFramework\Db\MultipleObjectsReturnedException;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
 
@@ -95,12 +96,25 @@ class ItemMapperV2 extends NewsMapperV2
         return $this->findEntity($builder);
     }
 
-    public function findByGuidHash(string $guidHash): Item
+    /**
+     * Find an item by a GUID hash.
+     *
+     * @param int    $feedId   ID of the feed
+     * @param string $guidHash hash to find with
+     *
+     * @return Item|Entity
+     *
+     * @throws DoesNotExistException
+     * @throws MultipleObjectsReturnedException
+     */
+    public function findByGuidHash(int $feedId, string $guidHash): Item
     {
         $builder = $this->db->getQueryBuilder();
         $builder->addSelect('*')
             ->from($this->tableName)
+            ->andWhere('feed_id = :feed_id')
             ->andWhere('guid_hash = :guid_hash')
+            ->setParameter(':feed_id', $feedId, IQueryBuilder::PARAM_INT)
             ->setParameter(':guid_hash', $guidHash, IQueryBuilder::PARAM_STR);
 
         return $this->findEntity($builder);
